@@ -32,16 +32,8 @@ using namespace bt;
 
 namespace kt
 {
-InfoWidgetPlugin::InfoWidgetPlugin(QObject *parent, const QVariantList &)
-    : Plugin(parent)
-    , peer_view(nullptr)
-    , cd_view(nullptr)
-    , tracker_view(nullptr)
-    , file_view(nullptr)
-    , status_tab(nullptr)
-    , webseeds_tab(nullptr)
-    , monitor(nullptr)
-    , pref(nullptr)
+InfoWidgetPlugin::InfoWidgetPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
 }
 
@@ -160,11 +152,6 @@ void InfoWidgetPlugin::currentTorrentChanged(bt::TorrentInterface *tc)
     createMonitor(tc);
 }
 
-bool InfoWidgetPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
-
 void InfoWidgetPlugin::applySettings()
 {
     // if the colors are invalid, set the default colors
