@@ -25,11 +25,9 @@ using namespace bt;
 
 namespace kt
 {
-ShutdownPlugin::ShutdownPlugin(QObject *parent, const QVariantList &args)
-    : Plugin(parent)
+ShutdownPlugin::ShutdownPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plugin(parent, data, args)
 {
-    Q_UNUSED(args);
-
     KActionCollection *ac = actionCollection();
     shutdown_enabled = new KToggleAction(QIcon::fromTheme(QStringLiteral("system-shutdown")), i18n("Shutdown Enabled"), this);
     connect(shutdown_enabled, &KToggleAction::toggled, this, &ShutdownPlugin::shutdownToggled);
@@ -46,11 +44,6 @@ ShutdownPlugin::~ShutdownPlugin()
 {
 }
 
-bool ShutdownPlugin::versionCheck(const QString &version) const
-{
-    return version == QStringLiteral(VERSION);
-}
-
 void ShutdownPlugin::unload()
 {
     rules->save(kt::DataDir() + QStringLiteral("shutdown_rules"));
